@@ -107,7 +107,8 @@ _NEOPIXEL_SHOW = const(0x05)
 
 _TOUCH_CHANNEL_OFFSET = const(0x10)
 
-_HW_ID_CODE = const(0x55)
+_SAMD09_HW_ID_CODE = const(0x55)
+_ATTINY8X7_HW_ID_CODE = const(0x87)
 _EEPROM_I2C_ADDR = const(0x3F)
 
 _ENCODER_STATUS = const(0x00)
@@ -126,33 +127,30 @@ class Seesaw:
 
     :param ~busio.I2C i2c_bus: Bus the SeeSaw is connected to
     :param int addr: I2C address of the SeeSaw device
-    :param ~digitalio.DigitalInOut drdy: Pin connected to SeeSaw's 'ready' output"""
+    :param ~digitalio.DigitalInOut drdy: Pin connected to SeeSaw's 'ready' output
+    :param bool reset: Whether to do a software reset on init"""
 
     INPUT = const(0x00)
     OUTPUT = const(0x01)
     INPUT_PULLUP = const(0x02)
     INPUT_PULLDOWN = const(0x03)
 
-    def __init__(self, i2c_bus, addr=0x49, drdy=None):
+    def __init__(self, i2c_bus, addr=0x49, drdy=None, reset=True):
         self._drdy = drdy
         if drdy is not None:
             drdy.switch_to_input()
 
         self.i2c_device = I2CDevice(i2c_bus, addr)
-        self.sw_reset()
+        if reset:
+            self.sw_reset()
 
-    def sw_reset(self):
-        """Trigger a software reset of the SeeSaw chip"""
-        self.write8(_STATUS_BASE, _STATUS_SWRST, 0xFF)
-        time.sleep(0.500)
+        self.chip_id = self.read8(_STATUS_BASE, _STATUS_HW_ID)
 
-        chip_id = self.read8(_STATUS_BASE, _STATUS_HW_ID)
-
-        if chip_id != _HW_ID_CODE:
+        if self.chip_id not in (_ATTINY8X7_HW_ID_CODE, _SAMD09_HW_ID_CODE):
             raise RuntimeError(
                 "Seesaw hardware ID returned (0x{:x}) is not "
-                "correct! Expected 0x{:x}. Please check your wiring.".format(
-                    chip_id, _HW_ID_CODE
+                "correct! Expected 0x{:x} or 0x{:x}. Please check your wiring.".format(
+                    self.chip_id, _SAMD09_HW_ID_CODE, _ATTINY8X7_HW_ID_CODE
                 )
             )
 
@@ -166,12 +164,21 @@ class Seesaw:
             from adafruit_seesaw.robohat import MM1_Pinmap
 
             self.pin_mapping = MM1_Pinmap
-        else:
+        elif self.chip_id == _SAMD09_HW_ID_CODE:
             from adafruit_seesaw.samd09 import SAMD09_Pinmap
 
             self.pin_mapping = SAMD09_Pinmap
+        elif self.chip_id == _ATTINY8X7_HW_ID_CODE:
+            from adafruit_seesaw.attiny8x7 import ATtiny8x7_Pinmap
+
+            self.pin_mapping = ATtiny8x7_Pinmap
         # pylint: enable=import-outside-toplevel
 
+    def sw_reset(self):
+        """Trigger a software reset of the SeeSaw chip"""
+        self.write8(_STATUS_BASE, _STATUS_SWRST, 0xFF)
+        time.sleep(0.500)
+
     def get_options(self):
         """Retrieve the 'options' word from the SeeSaw board"""
         buf = bytearray(4)
@@ -241,9 +248,14 @@ class Seesaw:
         if pin not in self.pin_mapping.analog_pins:
             raise ValueError("Invalid ADC pin")
 
+        if self.chip_id == _ATTINY8X7_HW_ID_CODE:
+            offset = pin
+        elif self.chip_id == _SAMD09_HW_ID_CODE:
+            offset = self.pin_mapping.analog_pins.index(pin)
+
         self.read(
             _ADC_BASE,
-            _ADC_CHANNEL_OFFSET + self.pin_mapping.analog_pins.index(pin),
+            _ADC_CHANNEL_OFFSET + offset,
             buf,
         )
         ret = struct.unpack(">H", buf)[0]
@@ -334,20 +346,19 @@ class Seesaw:
 
     def analog_write(self, pin, value):
         """Set the value of an analog output by number"""
-        pin_found = False
-        if self.pin_mapping.pwm_width == 16:
-            if pin in self.pin_mapping.pwm_pins:
-                pin_found = True
-                cmd = bytearray(
-                    [self.pin_mapping.pwm_pins.index(pin), (value >> 8), value & 0xFF]
-                )
-        else:
-            if pin in self.pin_mapping.pwm_pins:
-                pin_found = True
-                cmd = bytearray([self.pin_mapping.pwm_pins.index(pin), value])
-
-        if pin_found is False:
+        if pin not in self.pin_mapping.pwm_pins:
             raise ValueError("Invalid PWM pin")
+
+        if self.chip_id == _ATTINY8X7_HW_ID_CODE:
+            offset = pin
+        elif self.chip_id == _SAMD09_HW_ID_CODE:
+            offset = self.pin_mapping.pwm_pins.index(pin)
+
+        if self.pin_mapping.pwm_width == 16:
+            cmd = bytearray([offset, (value >> 8), value & 0xFF])
+        else:
+            cmd = bytearray([offset, value])
+
         self.write(_TIMER_BASE, _TIMER_PWM, cmd)
         time.sleep(0.001)
 
